##  Amazon Web Services (IaaS)
Infrastructure-as-a-Service (IaaS) is a service model that delivers computer infrastructure on an outsourced basis to support enterprise operations. Typically, IaaS provides hardware, storage, servers, and data center space or network components. The following diagrams show an example of how to model services of AWS as an IaaS solution in SAP LeanIX.
In this case, a sample web application called “My web application” uses several IT components, which represent popular services of AWS. Each IT component is connected to its respective Technology Stack and the Provider. As an example, we see that “My web application” uses the service CloudFront as a content delivery network (CDN). The first model shows the Technology Stacks on its lowest hierarchy level, while the second model uses the SAP LeanIX roll-up functionality, which shows the full hierarchy of the Technology Stacks.
![1896](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274cade77a441014a5b4fab16a76bb02_LowRes.png)![1910](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2741ae5c7a441014b7d5edc6d47bd643_LowRes.png)
As an alternative and simplified view on your AWS services, you can also use the drill-down functionality as shown in the following model.
![1924](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747e53c7a4410148ef6b9c728650991_LowRes.png)
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
